==> haskell-hspec-expectations-lifted-0.10.0-184-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations-lifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-8nyxnI8Eh6o8RDkMIWForW
key:                  hspec-expectations-lifted-0.10.0-8nyxnI8Eh6o8RDkMIWForW
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  9158fcc2e8648af1ccbd76c16ff864e1
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-8nyxnI8Eh6o8RDkMIWForW
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-8rXNbmLgMxC93hppG37Cwb
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-lifted-0.10.0-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations-lifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-KIzpmDprQ1V5s0RTf7R74E
key:                  hspec-expectations-lifted-0.10.0-KIzpmDprQ1V5s0RTf7R74E
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  935afe1d874e2edfdd3e79a90289755b
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-KIzpmDprQ1V5s0RTf7R74E
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
